"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAppSyncResourceName = exports.getAppSyncAuthConfig = exports.checkIfAuthExists = exports.authConfigHasApiKey = void 0;
exports.authConfigHasApiKey = authConfig => {
    if (!authConfig) {
        return false;
    }
    return (Array.of(authConfig.defaultAuthentication)
        .concat(authConfig.additionalAuthenticationProviders)
        .filter(auth => !!auth)
        .map(auth => auth.authenticationType)
        .findIndex(authType => authType === 'API_KEY') > -1);
};
exports.checkIfAuthExists = context => {
    const { amplify } = context;
    const { amplifyMeta } = amplify.getProjectDetails();
    let authResourceName;
    const authServiceName = 'Cognito';
    const authCategory = 'auth';
    if (amplifyMeta[authCategory] && Object.keys(amplifyMeta[authCategory]).length > 0) {
        const categoryResources = amplifyMeta[authCategory];
        Object.keys(categoryResources).forEach(resource => {
            if (categoryResources[resource].service === authServiceName) {
                authResourceName = resource;
            }
        });
    }
    return authResourceName;
};
exports.getAppSyncAuthConfig = projectMeta => {
    const entry = getAppSyncAmplifyMetaEntry(projectMeta);
    if (entry) {
        const value = entry[1];
        return value && value.output ? value.output.authConfig : {};
    }
};
exports.getAppSyncResourceName = (projectMeta) => {
    const entry = getAppSyncAmplifyMetaEntry(projectMeta);
    if (entry) {
        return entry[0];
    }
};
const getAppSyncAmplifyMetaEntry = (projectMeta) => {
    return Object.entries(projectMeta.api || {}).find(([, value]) => value.service === 'AppSync');
};
//# sourceMappingURL=amplify-meta-utils.js.map